Index: pkg/compiler/lib/src/io/source_information.dart |
diff --git a/pkg/compiler/lib/src/io/source_information.dart b/pkg/compiler/lib/src/io/source_information.dart |
index 0f6bbace841c906db35d20d054cee16bdb28cf79..cf3872cd0e35f229c23db196461c2f062247b6ad 100644 |
--- a/pkg/compiler/lib/src/io/source_information.dart |
+++ b/pkg/compiler/lib/src/io/source_information.dart |
@@ -5,7 +5,7 @@ |
library dart2js.source_information; |
import '../common.dart'; |
-import '../elements/elements.dart' show AstElement, LocalElement; |
+import '../elements/elements.dart' show AstElement, LocalElement, ResolvedAst; |
import '../js/js.dart' show JavaScriptNodeSourceInformation; |
import '../tree/tree.dart' show Node; |
import 'source_file.dart'; |
@@ -56,8 +56,9 @@ class SourceInformationBuilder { |
/// Create a [SourceInformationBuilder] for [element]. |
SourceInformationBuilder forContext(AstElement element) => this; |
- /// Generate [SourceInformation] the declaration of [element]. |
- SourceInformation buildDeclaration(AstElement element) => null; |
+ /// Generate [SourceInformation] the declaration of the element in |
+ /// [resolvedAst]. |
+ SourceInformation buildDeclaration(ResolvedAst resolvedAst) => null; |
/// Generate [SourceInformation] for the generic [node]. |
@deprecated |